@@ -1,4 +1,4 @@
-/* Time-stamp: <2006-01-12 19:01:29 poser>
+/* Time-stamp: <2006-07-03 22:12:40 poser>
  *
  * This function reads from a file descriptor presumed to contain text encoded
  * in UTF-8 and returns the next UTF-32 character. It performs the same
@@ -11,7 +11,8 @@
  * This version "returns" via pointers passed as arguments the number of bytes read
  * and a pointer to the raw byte string.
  * 
- * Author: Bill Poser (wjposer@unagi.cis.upenn.edu)
+ * Author: Bill Poser (billposer@alum.mit.edu)
+ * Patch by Dylan Thurston to resume read interrupted in mid-sequence.
  *
  */
 
@@ -86,6 +87,7 @@ static Boolean LegalUTF8P(const UTF8 *source, int length) {
 
 UTF32 Get_UTF32_From_UTF8 (int fd, int *bytes, unsigned char **bstr)
 {
+  int BytesSoFar;
   int BytesRead;
   int BytesNeeded;		/* Additional bytes after initial byte */
   static unsigned char c[6];
@@ -102,9 +104,13 @@ UTF32 Get_UTF32_From_UTF8 (int fd, int *bytes, unsigned char **bstr)
 
   /* Now get the remaining bytes */
   BytesNeeded = (int) TrailingBytesForUTF8[c[0]];
-  BytesRead = read(fd,(void *) &c[1],(size_t) BytesNeeded);
-  if(BytesRead != BytesNeeded) return(UTF8_NOTENOUGHBYTES);
-  *bytes = BytesRead+1;
+  BytesSoFar = 0;
+  do {
+    BytesRead = read(fd,(void *) &c[BytesSoFar+1],(size_t) (BytesNeeded-BytesSoFar));
+    BytesSoFar += BytesRead;
+  } while (BytesRead > 0 || BytesSoFar < BytesNeeded);
+  if(BytesSoFar != BytesNeeded) return(UTF8_NOTENOUGHBYTES);
+  *bytes = BytesNeeded+1;
   *bstr = &c[0];
 
   /* Check validity of source */
