@@ -1,4 +1,4 @@
-/* Time-stamp: <2006-04-17 19:06:02 poser>
+/* Time-stamp: <2006-07-05 17:38:59 poser>
  *
  * Convert text containing various 7-bit ASCII escapes to UTF-7 Unicode.
  *
@@ -68,7 +68,7 @@ containing various representations for non-ASCII characters\nto UTF-8 Unicode.\n
   fprintf(stderr,_("       -h Print this usage message.\n"));
   fprintf(stderr,_("       -q Quiet - don't chat.\n"));
   fprintf(stderr,_("       -v Print version information.\n"));
-  fprintf(stderr,_("       -p Pure. The input consists of escapes separated by whitespace.\n"));
+  fprintf(stderr,_("       -8 Convert only tokens above the ASCII range.\n"));
   fprintf(stderr,_("   Give at most one of the following conversion specifications:\n"));
   fprintf(stderr,
 	  _("       -A Convert hexadecimal numbers with prefix U in angle-brackets(<U00E9>)\n"));
@@ -154,7 +154,7 @@ int main (int ac, char *av[])
   char *Tfmt = "\\d%03d\\d%03d\\d%03d";
   char *Ufmt = "\\u%8lX";
   char *Vfmt = "\\u%8ld";
-  char *Xfmt = "0x%lX";
+  char *Xfmt = "0x%4lX";
 
   char *fmt = Xfmt;		/* Default is plain hex format */
   char afmt [67+2+1+2];
